@@ -61,9 +61,9 @@ class BuildBoilerplateTest(unittest.TestCase):
                                                    dst))
 
         with open(answer, 'r') as f:
-            html1 = f.read()
+            html1 = f.read().replace('\r\n', '\n')
         with open(copyTo, 'r') as f:
-            html2 = f.read()
+            html2 = f.read().replace('\r\n', '\n')
         
         self.assertEqual(html1, html2)
         if delete:
@@ -124,9 +124,9 @@ class BuildBoilerplateTest(unittest.TestCase):
 
         with open(
             os.path.join(STATIC_DIT_PATH, 'js', 'FixTemplate.js'), 'r') as f:
-            js1 = f.read()
+            js1 = f.read().replace('\r\n', '\n')
         with open(os.path.join(HTML_DIR_PATH, 'AttrJsAnswer.js'), 'r') as f:
-            js2 = f.read()
+            js2 = f.read().replace('\r\n', '\n')
 
         self.assertEqual(js1, js2)
         self.reset()
